// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KSANE_VERSION_H
#define KSANE_VERSION_H

#define KSANE_VERSION_STRING "26.04.3"
#define KSANE_VERSION_MAJOR 26
#define KSANE_VERSION_MINOR 4
#define KSANE_VERSION_PATCH 3
#define KSANE_VERSION ((26<<16)|(4<<8)|(3))

#endif
